summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lisp/gnus/ChangeLog52
-rw-r--r--lisp/gnus/gnus-agent.el4
-rw-r--r--lisp/gnus/gnus-art.el2
-rw-r--r--lisp/gnus/gnus-cache.el4
-rw-r--r--lisp/gnus/gnus-group.el4
-rw-r--r--lisp/gnus/gnus-score.el8
-rw-r--r--lisp/gnus/gnus-soup.el8
-rw-r--r--lisp/gnus/gnus-spec.el2
-rw-r--r--lisp/gnus/gnus-start.el2
-rw-r--r--lisp/gnus/gnus-sum.el2
-rw-r--r--lisp/gnus/gnus-uu.el2
-rw-r--r--lisp/gnus/nnbabyl.el2
-rw-r--r--lisp/gnus/nndb.el2
-rw-r--r--lisp/gnus/nndiary.el16
-rw-r--r--lisp/gnus/nndoc.el4
-rw-r--r--lisp/gnus/nndraft.el4
-rw-r--r--lisp/gnus/nneething.el2
-rw-r--r--lisp/gnus/nnfolder.el6
-rw-r--r--lisp/gnus/nnheader.el4
-rw-r--r--lisp/gnus/nnkiboze.el2
-rw-r--r--lisp/gnus/nnmail.el4
-rw-r--r--lisp/gnus/nnmbox.el4
-rw-r--r--lisp/gnus/nnmh.el12
-rw-r--r--lisp/gnus/nnml.el4
-rw-r--r--lisp/gnus/nnrss.el2
-rw-r--r--lisp/gnus/nnsoup.el4
-rw-r--r--lisp/gnus/nnspool.el4
-rw-r--r--lisp/gnus/nntp.el6
-rw-r--r--lisp/gnus/pgg-gpg.el2
-rw-r--r--lisp/gnus/pgg-parse.el6
-rw-r--r--lisp/gnus/pop3.el6
-rw-r--r--lisp/gnus/qp.el6
-rw-r--r--lisp/gnus/spam-report.el4
33 files changed, 124 insertions, 72 deletions
diff --git a/lisp/gnus/ChangeLog b/lisp/gnus/ChangeLog
index 16db594bf01..1f8f23bbf18 100644
--- a/lisp/gnus/ChangeLog
+++ b/lisp/gnus/ChangeLog
@@ -1,3 +1,55 @@
+2005-05-30 Reiner Steib <Reiner.Steib@gmx.de>
+
+ * gnus-agent.el (gnus-agent-regenerate-group)
+ (gnus-agent-fetch-articles): Replace `string-to-int' by
+ `string-to-number'.
+ * gnus-art.el (gnus-button-fetch-group): Ditto.
+ * gnus-cache.el (gnus-cache-generate-active)
+ (gnus-cache-articles-in-group): Ditto.
+ * gnus-group.el (gnus-group-set-current-level)
+ (gnus-group-insert-group-line): Ditto.
+ * gnus-score.el (gnus-score-set-expunge-below)
+ (gnus-score-set-mark-below, gnus-summary-score-effect)
+ (gnus-summary-score-entry): Ditto.
+ * gnus-soup.el (gnus-soup-send-packet, gnus-soup-parse-areas)
+ (gnus-soup-pack): Ditto.
+ * gnus-spec.el (gnus-xmas-format): Ditto.
+ * gnus-start.el (gnus-newsrc-to-gnus-format): Ditto.
+ * gnus-sum.el (gnus-create-xref-hashtb): Ditto.
+ * gnus-uu.el (gnus-uu-expand-numbers): Ditto.
+ * nnbabyl.el (nnbabyl-article-group-number): Ditto.
+ * nndb.el (nndb-get-remote-expire-response): Ditto.
+ * nndiary.el (nndiary-parse-schedule-value)
+ (nndiary-string-to-number, nndiary-request-replace-article)
+ (nndiary-request-article): Ditto.
+ * nndoc.el (nndoc-rnews-body-end, nndoc-mbox-body-end): Ditto.
+ * nndraft.el (nndraft-articles, nndraft-request-group): Ditto.
+ * nneething.el (nneething-make-head): Ditto.
+ * nnfolder.el (nnfolder-request-article)
+ (nnfolder-retrieve-headers): Ditto.
+ * nnheader.el (nnheader-file-to-number): Ditto.
+ * nnkiboze.el (nnkiboze-request-article): Ditto.
+ * nnmail.el (nnmail-process-unix-mail-format)
+ (nnmail-process-babyl-mail-format): Ditto.
+ * nnmbox.el (nnmbox-read-mbox, nnmbox-article-group-number): Ditto.
+ * nnmh.el (nnmh-update-gnus-unreads, nnmh-active-number)
+ (nnmh-request-create-group, nnmh-request-list-1)
+ (nnmh-request-group, nnmh-request-article): Ditto.
+ * nnml.el (nnml-request-replace-article, nnml-request-article): Ditto.
+ * nnrss.el (nnrss-find-rss-via-syndic8): Ditto.
+ * nnsoup.el (nnsoup-make-active): Ditto.
+ * nnspool.el (nnspool-find-id, nnspool-request-group): Ditto.
+ * nntp.el (nntp-find-group-and-number)
+ (nntp-retrieve-headers-with-xover): Ditto.
+ * pgg-gpg.el (pgg-gpg-snarf-keys-region): Ditto.
+ * pgg-parse.el (pgg-read-body, pgg-read-bytes)
+ (pgg-format-key-identifier): Ditto.
+ * pop3.el (pop3-last, pop3-stat): Ditto.
+ * qp.el (quoted-printable-decode-region): Ditto.
+
+ * spam-report.el (spam-report-url-ping-mm-url): Use format instead
+ of concat.
+
2005-05-30 Katsumi Yamaoka <yamaoka@jpl.org>
* gnus-agent.el (gnus-category-mode): Use gnus-run-mode-hooks.
diff --git a/lisp/gnus/gnus-agent.el b/lisp/gnus/gnus-agent.el
index 3d353d1ba56..9f4525e1ae2 100644
--- a/lisp/gnus/gnus-agent.el
+++ b/lisp/gnus/gnus-agent.el
@@ -1540,7 +1540,7 @@ downloaded into the agent."
(while (looking-at "\\([^: \n]+\\):\\([0-9]+\\) *")
(push (cons (buffer-substring (match-beginning 1)
(match-end 1))
- (string-to-int
+ (string-to-number
(buffer-substring (match-beginning 2)
(match-end 2))))
crosses)
@@ -3703,7 +3703,7 @@ If REREAD is not nil, downloaded articles are marked as unread."
(dir (file-name-directory file))
point
(downloaded (if (file-exists-p dir)
- (sort (mapcar (lambda (name) (string-to-int name))
+ (sort (mapcar (lambda (name) (string-to-number name))
(directory-files dir nil "^[0-9]+$" t))
'>)
(progn (gnus-make-directory dir) nil)))
diff --git a/lisp/gnus/gnus-art.el b/lisp/gnus/gnus-art.el
index 70096b58729..c3076cbb22e 100644
--- a/lisp/gnus/gnus-art.el
+++ b/lisp/gnus/gnus-art.el
@@ -6787,7 +6787,7 @@ specified by `gnus-button-alist'."
(match-string 3 address)
"nntp")))
nil nil nil
- (and (match-end 6) (list (string-to-int (match-string 6 address))))))))
+ (and (match-end 6) (list (string-to-number (match-string 6 address))))))))
(defun gnus-url-parse-query-string (query &optional downcase)
(let (retval pairs cur key val)
diff --git a/lisp/gnus/gnus-cache.el b/lisp/gnus/gnus-cache.el
index 657ade98167..55544d1525c 100644
--- a/lisp/gnus/gnus-cache.el
+++ b/lisp/gnus/gnus-cache.el
@@ -487,7 +487,7 @@ Returns the list of articles removed."
articles)
(when (file-exists-p dir)
(setq articles
- (sort (mapcar (lambda (name) (string-to-int name))
+ (sort (mapcar (lambda (name) (string-to-number name))
(directory-files dir nil "^[0-9]+$" t))
'<))
;; Update the cache active file, just to synch more.
@@ -681,7 +681,7 @@ If LOW, update the lower bound instead."
;; Separate articles from all other files and directories.
(while files
(if (string-match "^[0-9]+$" (file-name-nondirectory (car files)))
- (push (string-to-int (file-name-nondirectory (pop files))) nums)
+ (push (string-to-number (file-name-nondirectory (pop files))) nums)
(push (pop files) alphs)))
;; If we have nums, then this is probably a valid group.
(when (setq nums (sort nums '<))
diff --git a/lisp/gnus/gnus-group.el b/lisp/gnus/gnus-group.el
index 44d59729b6f..578e74d2a0e 100644
--- a/lisp/gnus/gnus-group.el
+++ b/lisp/gnus/gnus-group.el
@@ -1452,7 +1452,7 @@ if it is a string, only list groups matching REGEXP."
(eval gnus-group-line-format-spec)))
`(gnus-group ,(gnus-intern-safe gnus-tmp-group gnus-active-hashtb)
gnus-unread ,(if (numberp number)
- (string-to-int gnus-tmp-number-of-unread)
+ (string-to-number gnus-tmp-number-of-unread)
t)
gnus-marked ,gnus-tmp-marked-mark
gnus-indentation ,gnus-group-indentation
@@ -3246,7 +3246,7 @@ Uses the process/prefix convention."
(progn
(unless (gnus-group-process-prefix current-prefix-arg)
(error "No group on the current line"))
- (string-to-int
+ (string-to-number
(let ((s (read-string
(format "Level (default %s): "
(or (gnus-group-group-level)
diff --git a/lisp/gnus/gnus-score.el b/lisp/gnus/gnus-score.el
index 3a22f9030e5..a2c3b249343 100644
--- a/lisp/gnus/gnus-score.el
+++ b/lisp/gnus/gnus-score.el
@@ -826,7 +826,7 @@ If optional argument `EXTRA' is non-nil, it's a non-standard overview header."
;; If this is an integer comparison, we transform from string to int.
(if (eq (nth 2 (assoc header gnus-header-index)) 'gnus-score-integer)
(if (stringp match)
- (setq match (string-to-int match)))
+ (setq match (string-to-number match)))
(set-text-properties 0 (length match) nil match))
(unless (eq date 'now)
@@ -891,7 +891,7 @@ EXTRA is the possible non-standard header."
t)
(read-string "Match: ")
(if (y-or-n-p "Use regexp match? ") 'r 's)
- (string-to-int (read-string "Score: "))))
+ (string-to-number (read-string "Score: "))))
(save-excursion
(unless (and (stringp match) (> (length match) 0))
(error "No match"))
@@ -945,7 +945,7 @@ EXTRA is the possible non-standard header."
"Automatically mark articles with score below SCORE as read."
(interactive
(list (or (and current-prefix-arg (prefix-numeric-value current-prefix-arg))
- (string-to-int (read-string "Mark below: ")))))
+ (string-to-number (read-string "Mark below: ")))))
(setq score (or score gnus-summary-default-score 0))
(gnus-score-set 'mark (list score))
(gnus-score-set 'touched '(t))
@@ -979,7 +979,7 @@ EXTRA is the possible non-standard header."
"Automatically expunge articles with score below SCORE."
(interactive
(list (or (and current-prefix-arg (prefix-numeric-value current-prefix-arg))
- (string-to-int (read-string "Set expunge below: ")))))
+ (string-to-number (read-string "Set expunge below: ")))))
(setq score (or score gnus-summary-default-score 0))
(gnus-score-set 'expunge (list score))
(gnus-score-set 'touched '(t)))
diff --git a/lisp/gnus/gnus-soup.el b/lisp/gnus/gnus-soup.el
index 55dc1635542..48a8fc0c380 100644
--- a/lisp/gnus/gnus-soup.el
+++ b/lisp/gnus/gnus-soup.el
@@ -349,9 +349,9 @@ If NOT-ALL, don't pack ticked articles."
(packer (if (< (string-match "%s" packer)
(string-match "%d" packer))
(format packer files
- (string-to-int (gnus-soup-unique-prefix dir)))
+ (string-to-number (gnus-soup-unique-prefix dir)))
(format packer
- (string-to-int (gnus-soup-unique-prefix dir))
+ (string-to-number (gnus-soup-unique-prefix dir))
files)))
(dir (expand-file-name dir)))
(gnus-make-directory dir)
@@ -385,7 +385,7 @@ though the two last may be nil if they are missing."
(and (eq (preceding-char) ?\t)
(gnus-soup-field))
(and (eq (preceding-char) ?\t)
- (string-to-int (gnus-soup-field))))
+ (string-to-number (gnus-soup-field))))
areas)
(when (eq (preceding-char) ?\t)
(beginning-of-line 2)))
@@ -535,7 +535,7 @@ Return whether the unpacking was successful."
(error "Bad header"))
(forward-line 1)
(setq beg (point)
- end (+ (point) (string-to-int
+ end (+ (point) (string-to-number
(buffer-substring
(match-beginning 1) (match-end 1)))))
(switch-to-buffer tmp-buf)
diff --git a/lisp/gnus/gnus-spec.el b/lisp/gnus/gnus-spec.el
index ef1c43167f5..39b87727279 100644
--- a/lisp/gnus/gnus-spec.el
+++ b/lisp/gnus/gnus-spec.el
@@ -509,7 +509,7 @@ are supported for %s."
(t
(if (null args)
(error 'wrong-number-of-arguments #'my-format n fstring))
- (let* ((minlen (string-to-int (or (match-string 2) "")))
+ (let* ((minlen (string-to-number (or (match-string 2) "")))
(arg (car args))
(str (if (stringp arg) arg (format "%s" arg)))
(lpad (null (match-string 1)))
diff --git a/lisp/gnus/gnus-start.el b/lisp/gnus/gnus-start.el
index 6eec4f4e846..785ad87a2ee 100644
--- a/lisp/gnus/gnus-start.el
+++ b/lisp/gnus/gnus-start.el
@@ -2517,7 +2517,7 @@ If FORCE is non-nil, the .newsrc file is read."
(cond
((looking-at "[0-9]+")
;; We narrow and read a number instead of buffer-substring/
- ;; string-to-int because it's faster. narrow/widen is
+ ;; string-to-number because it's faster. narrow/widen is
;; faster than save-restriction/narrow, and save-restriction
;; produces a garbage object.
(setq num1 (progn
diff --git a/lisp/gnus/gnus-sum.el b/lisp/gnus/gnus-sum.el
index fd44e475ddd..8d4c536229b 100644
--- a/lisp/gnus/gnus-sum.el
+++ b/lisp/gnus/gnus-sum.el
@@ -5660,7 +5660,7 @@ The resulting hash table is returned, or nil if no Xrefs were found."
(match-end 1)))
(substring xrefs (match-beginning 1) (match-end 1))))
(setq number
- (string-to-int (substring xrefs (match-beginning 2)
+ (string-to-number (substring xrefs (match-beginning 2)
(match-end 2))))
(if (setq entry (gnus-gethash group xref-hashtb))
(setcdr entry (cons number (cdr entry)))
diff --git a/lisp/gnus/gnus-uu.el b/lisp/gnus/gnus-uu.el
index 3b2a29c238e..a705f230241 100644
--- a/lisp/gnus/gnus-uu.el
+++ b/lisp/gnus/gnus-uu.el
@@ -1185,7 +1185,7 @@ When called interactively, prompt for REGEXP."
(ignore-errors
(replace-match
(format "%06d"
- (string-to-int (buffer-substring
+ (string-to-number (buffer-substring
(match-beginning 0) (match-end 0)))))))
(setq string (buffer-substring 1 (point-max)))
(setcar (car string-list) string)
diff --git a/lisp/gnus/nnbabyl.el b/lisp/gnus/nnbabyl.el
index e69b6a0304a..dae51fca50b 100644
--- a/lisp/gnus/nnbabyl.el
+++ b/lisp/gnus/nnbabyl.el
@@ -493,7 +493,7 @@
(when (re-search-forward "^X-Gnus-Newsgroup: +\\([^:]+\\):\\([0-9]+\\) "
nil t)
(cons (buffer-substring (match-beginning 1) (match-end 1))
- (string-to-int
+ (string-to-number
(buffer-substring (match-beginning 2) (match-end 2)))))))
(defun nnbabyl-insert-lines ()
diff --git a/lisp/gnus/nndb.el b/lisp/gnus/nndb.el
index 6aaf57c81e1..fe4072c5d35 100644
--- a/lisp/gnus/nndb.el
+++ b/lisp/gnus/nndb.el
@@ -196,7 +196,7 @@ article was posted to nndb")
;; otherwise, pull all of the following numbers into the list
(re-search-forward "follows\r?\n?" nil t)
(while (re-search-forward "^[0-9]+$" nil t)
- (push (string-to-int (match-string 0)) list)))
+ (push (string-to-number (match-string 0)) list)))
list))
(defun nndb-request-expire-articles-remote
diff --git a/lisp/gnus/nndoc.el b/lisp/gnus/nndoc.el
index 47a3cbd0292..a7948365680 100644
--- a/lisp/gnus/nndoc.el
+++ b/lisp/gnus/nndoc.el
@@ -421,7 +421,7 @@ from the document.")
(search-forward "\n\n" beg t)
(re-search-backward
"^Content-Length:[ \t]*\\([0-9]+\\) *$" end t)
- (setq len (string-to-int (match-string 1)))
+ (setq len (string-to-number (match-string 1)))
(search-forward "\n\n" beg t)
(unless (= (setq len (+ (point) len)) (point-max))
(and (< len (point-max))
@@ -444,7 +444,7 @@ from the document.")
(defun nndoc-rnews-body-end ()
(and (re-search-backward nndoc-article-begin nil t)
(forward-line 1)
- (goto-char (+ (point) (string-to-int (match-string 1))))))
+ (goto-char (+ (point) (string-to-number (match-string 1))))))
(defun nndoc-babyl-type-p ()
(when (re-search-forward "\^_\^L *\n" nil t)
diff --git a/lisp/gnus/nndraft.el b/lisp/gnus/nndraft.el
index 9235bf72a29..a71376155c1 100644
--- a/lisp/gnus/nndraft.el
+++ b/lisp/gnus/nndraft.el
@@ -185,7 +185,7 @@
(file-name-coding-system nnmail-pathname-coding-system)
dir file)
(nnheader-re-read-dir pathname)
- (setq dir (mapcar (lambda (name) (string-to-int (substring name 1)))
+ (setq dir (mapcar (lambda (name) (string-to-number (substring name 1)))
(ignore-errors (directory-files
pathname nil "^#[0-9]+#$" t))))
(dolist (n dir)
@@ -293,7 +293,7 @@
"Return the list of messages in the group."
(gnus-make-directory nndraft-current-directory)
(sort
- (mapcar 'string-to-int
+ (mapcar 'string-to-number
(directory-files nndraft-current-directory nil "\\`[0-9]+\\'" t))
'<))
diff --git a/lisp/gnus/nneething.el b/lisp/gnus/nneething.el
index d7698efb845..61f8eefbf17 100644
--- a/lisp/gnus/nneething.el
+++ b/lisp/gnus/nneething.el
@@ -329,7 +329,7 @@ included.")
(when (re-search-forward "<[a-zA-Z0-9_]@[-a-zA-Z0-9_]>" 1000 t)
(concat "From: " (match-string 0) "\n"))))
(nneething-from-line (nth 2 atts) file))
- (if (> (string-to-int (int-to-string (nth 7 atts))) 0)
+ (if (> (string-to-number (int-to-string (nth 7 atts))) 0)
(concat "Chars: " (int-to-string (nth 7 atts)) "\n")
"")
(if buffer
diff --git a/lisp/gnus/nnfolder.el b/lisp/gnus/nnfolder.el
index f50530ab459..961f124a614 100644
--- a/lisp/gnus/nnfolder.el
+++ b/lisp/gnus/nnfolder.el
@@ -200,7 +200,7 @@ the group. Then the marks file will be regenerated properly by Gnus.")
((search-backward (concat "\n" nnfolder-article-marker)
nil t)
(goto-char (match-end 0))
- (setq num (string-to-int
+ (setq num (string-to-number
(buffer-substring
(point) (gnus-point-at-eol))))
(goto-char start)
@@ -210,7 +210,7 @@ the group. Then the marks file will be regenerated properly by Gnus.")
(search-forward (concat "\n" nnfolder-article-marker)
nil t)
(progn
- (setq num (string-to-int
+ (setq num (string-to-number
(buffer-substring
(point) (gnus-point-at-eol))))
(> num article))
@@ -285,7 +285,7 @@ the group. Then the marks file will be regenerated properly by Gnus.")
(cons nnfolder-current-group
(if (search-forward (concat "\n" nnfolder-article-marker)
nil t)
- (string-to-int (buffer-substring
+ (string-to-number (buffer-substring
(point) (gnus-point-at-eol)))
-1))))))))
diff --git a/lisp/gnus/nnheader.el b/lisp/gnus/nnheader.el
index 6224f9718f1..c55252e5b64 100644
--- a/lisp/gnus/nnheader.el
+++ b/lisp/gnus/nnheader.el
@@ -683,9 +683,9 @@ the line could be found."
(defsubst nnheader-file-to-number (file)
"Take a FILE name and return the article number."
(if (string= nnheader-numerical-short-files "^[0-9]+$")
- (string-to-int file)
+ (string-to-number file)
(string-match nnheader-numerical-short-files file)
- (string-to-int (match-string 0 file))))
+ (string-to-number (match-string 0 file))))
(defvar nnheader-directory-files-is-safe
(or (eq system-type 'windows-nt)
diff --git a/lisp/gnus/nnkiboze.el b/lisp/gnus/nnkiboze.el
index f68bb8b5f55..f6766836fe1 100644
--- a/lisp/gnus/nnkiboze.el
+++ b/lisp/gnus/nnkiboze.el
@@ -106,7 +106,7 @@
(error "nnkiboze: No xref"))
(unless (string-match " \\([^ ]+\\):\\([0-9]+\\)" xref)
(error "nnkiboze: Malformed xref"))
- (setq num (string-to-int (match-string 2 xref))
+ (setq num (string-to-number (match-string 2 xref))
group (match-string 1 xref))
(or (with-current-buffer buffer
(or (and gnus-use-cache (gnus-cache-request-article num group))
diff --git a/lisp/gnus/nnmail.el b/lisp/gnus/nnmail.el
index c0689335f67..affe72c75c8 100644
--- a/lisp/gnus/nnmail.el
+++ b/lisp/gnus/nnmail.el
@@ -769,7 +769,7 @@ If SOURCE is a directory spec, try to return the group name component."
(if (not (save-excursion
(and (re-search-backward
"^Content-Length:[ \t]*\\([0-9]+\\)" start t)
- (setq content-length (string-to-int
+ (setq content-length (string-to-number
(buffer-substring
(match-beginning 1)
(match-end 1))))
@@ -906,7 +906,7 @@ If SOURCE is a directory spec, try to return the group name component."
(if (not (re-search-forward
"^Content-Length:[ \t]*\\([0-9]+\\)" nil t))
(setq content-length nil)
- (setq content-length (string-to-int (match-string 1)))
+ (setq content-length (string-to-number (match-string 1)))
;; We destroy the header, since none of the backends ever
;; use it, and we do not want to confuse other mailers by
;; having a (possibly) faulty header.
diff --git a/lisp/gnus/nnmbox.el b/lisp/gnus/nnmbox.el
index a1957fa0dcd..42721f2e92e 100644
--- a/lisp/gnus/nnmbox.el
+++ b/lisp/gnus/nnmbox.el
@@ -475,7 +475,7 @@
(when (re-search-forward "^X-Gnus-Newsgroup: +\\([^:]+\\):\\([0-9]+\\) "
nil t)
(cons (buffer-substring (match-beginning 1) (match-end 1))
- (string-to-int
+ (string-to-number
(buffer-substring (match-beginning 2) (match-end 2)))))))
(defun nnmbox-in-header-p (pos)
@@ -681,7 +681,7 @@
(let (alist)
(while (re-search-forward " \\([^:]+\\):\\([0-9]+\\)" end-header t)
(push (cons (match-string 1)
- (string-to-int (match-string 2))) alist))
+ (string-to-number (match-string 2))) alist))
(nnmbox-insert-newsgroup-line alist))
;; this is really a new article
(nnmbox-save-mail
diff --git a/lisp/gnus/nnmh.el b/lisp/gnus/nnmh.el
index 37f0bb353e8..af99217fe6d 100644
--- a/lisp/gnus/nnmh.el
+++ b/lisp/gnus/nnmh.el
@@ -150,7 +150,7 @@ as unread by Gnus.")
(file-exists-p file)
(not (file-directory-p file))
(save-excursion (nnmail-find-file file))
- (string-to-int (file-name-nondirectory file)))))
+ (string-to-number (file-name-nondirectory file)))))
(deffoo nnmh-request-group (group &optional server dont-check)
(nnheader-init-server-buffer)
@@ -176,7 +176,7 @@ as unread by Gnus.")
(nnheader-re-read-dir pathname)
(setq dir
(sort
- (mapcar (lambda (name) (string-to-int name))
+ (mapcar (lambda (name) (string-to-number name))
(directory-files pathname nil "^[0-9]+$" t))
'<))
(cond
@@ -224,7 +224,7 @@ as unread by Gnus.")
;; For each directory, generate an active file line.
(unless (string= (expand-file-name nnmh-toplev) dir)
(let ((files (mapcar
- (lambda (name) (string-to-int name))
+ (lambda (name) (string-to-number name))
(directory-files dir nil "^[0-9]+$" t))))
(when files
(save-excursion
@@ -358,7 +358,7 @@ as unread by Gnus.")
(nnmh-possibly-change-directory group server)
(let ((articles (mapcar
(lambda (file)
- (string-to-int file))
+ (string-to-number file))
(directory-files
nnmh-current-directory nil "^[0-9]+$"))))
(when articles
@@ -486,7 +486,7 @@ as unread by Gnus.")
(let ((files (sort
(mapcar
(lambda (f)
- (string-to-int f))
+ (string-to-number f))
(directory-files dir nil "^[0-9]+$"))
'>)))
(when files
@@ -509,7 +509,7 @@ as unread by Gnus.")
;; articles in this folder. The articles that are "new" will be
;; marked as unread by Gnus.
(let* ((dir nnmh-current-directory)
- (files (sort (mapcar (function (lambda (name) (string-to-int name)))
+ (files (sort (mapcar (function (lambda (name) (string-to-number name)))
(directory-files nnmh-current-directory
nil "^[0-9]+$" t))
'<))
diff --git a/lisp/gnus/nnml.el b/lisp/gnus/nnml.el
index b82df8f979a..f330fa97a5a 100644
--- a/lisp/gnus/nnml.el
+++ b/lisp/gnus/nnml.el
@@ -212,7 +212,7 @@ marks file will be regenerated properly by Gnus.")
(nnheader-report 'nnml "Article %s retrieved" id)
;; We return the article number.
(cons (if group-num (car group-num) group)
- (string-to-int (file-name-nondirectory path)))))))
+ (string-to-number (file-name-nondirectory path)))))))
(deffoo nnml-request-group (group &optional server dont-check)
(let ((file-name-coding-system nnmail-pathname-coding-system))
@@ -426,7 +426,7 @@ marks file will be regenerated properly by Gnus.")
;; we should insert it. (This situation should never
;; occur, but one likes to make sure...)
(while (and (looking-at "[0-9]+\t")
- (< (string-to-int
+ (< (string-to-number
(buffer-substring
(match-beginning 0) (match-end 0)))
article)
diff --git a/lisp/gnus/nnrss.el b/lisp/gnus/nnrss.el
index 42ab072f438..ee5d6560354 100644
--- a/lisp/gnus/nnrss.el
+++ b/lisp/gnus/nnrss.el
@@ -899,7 +899,7 @@ whether they are `offsite' or `onsite'."
(selection
(mapcar (lambda (listinfo)
(cons (cdr (assoc "sitename" listinfo))
- (string-to-int
+ (string-to-number
(cdr (assoc "feedid" listinfo)))))
feedinfo)))
(cdr (assoc
diff --git a/lisp/gnus/nnsoup.el b/lisp/gnus/nnsoup.el
index 9c69b1d3c63..836d97e1e42 100644
--- a/lisp/gnus/nnsoup.el
+++ b/lisp/gnus/nnsoup.el
@@ -752,9 +752,9 @@ backend for the messages.")
(let ((files (sort (directory-files nnsoup-directory t "IDX$")
(lambda (f1 f2)
(< (progn (string-match "/\\([0-9]+\\)\\." f1)
- (string-to-int (match-string 1 f1)))
+ (string-to-number (match-string 1 f1)))
(progn (string-match "/\\([0-9]+\\)\\." f2)
- (string-to-int (match-string 1 f2)))))))
+ (string-to-number (match-string 1 f2)))))))
active group lines ident elem min)
(set-buffer (get-buffer-create " *nnsoup work*"))
(while files
diff --git a/lisp/gnus/nnspool.el b/lisp/gnus/nnspool.el
index d54897a7750..6418c96d931 100644
--- a/lisp/gnus/nnspool.el
+++ b/lisp/gnus/nnspool.el
@@ -248,7 +248,7 @@ there.")
;; Fix by Sudish Joseph <joseph@cis.ohio-state.edu>
(when (setq dir (directory-files pathname nil "^[0-9]+$" t))
(setq dir
- (sort (mapcar (lambda (name) (string-to-int name)) dir) '<)))
+ (sort (mapcar (lambda (name) (string-to-number name)) dir) '<)))
(if dir
(nnheader-insert
"211 %d %d %d %s\n" (length dir) (car dir)
@@ -440,7 +440,7 @@ there.")
(goto-char (point-min))
(prog1
(when (looking-at "<[^>]+>[ \t]+[-0-9~]+[ \t]+\\([^ /\t\n]+\\)/\\([0-9]+\\)[ \t\n]")
- (cons (match-string 1) (string-to-int (match-string 2))))
+ (cons (match-string 1) (string-to-number (match-string 2))))
(kill-buffer (current-buffer)))))
(defun nnspool-find-file (file)
diff --git a/lisp/gnus/nntp.el b/lisp/gnus/nntp.el
index ab85ad25931..1c964a5706c 100644
--- a/lisp/gnus/nntp.el
+++ b/lisp/gnus/nntp.el
@@ -1499,7 +1499,7 @@ password contained in '~/.nntp-authinfo'."
(when (<= count 1)
(goto-char (point-min))
(when (re-search-forward "^[0-9][0-9][0-9] .*\n\\([0-9]+\\)" nil t)
- (let ((low-limit (string-to-int
+ (let ((low-limit (string-to-number
(buffer-substring (match-beginning 1)
(match-end 1)))))
(while (and articles (<= (car articles) low-limit))
@@ -1571,7 +1571,7 @@ password contained in '~/.nntp-authinfo'."
(goto-char (point-min))
;; We first find the number by looking at the status line.
(let ((number (and (looking-at "2[0-9][0-9] +\\([0-9]+\\) ")
- (string-to-int
+ (string-to-number
(buffer-substring (match-beginning 1)
(match-end 1)))))
newsgroups xref)
@@ -1609,7 +1609,7 @@ password contained in '~/.nntp-authinfo'."
"\\([^ :]+\\):\\([0-9]+\\)")
xref))
(setq group (match-string 1 xref)
- number (string-to-int (match-string 2 xref))))
+ number (string-to-number (match-string 2 xref))))
((and (setq newsgroups
(mail-fetch-field "newsgroups"))
(not (string-match "," newsgroups)))
diff --git a/lisp/gnus/pgg-gpg.el b/lisp/gnus/pgg-gpg.el
index 2b3e521c60f..463020838c9 100644
--- a/lisp/gnus/pgg-gpg.el
+++ b/lisp/gnus/pgg-gpg.el
@@ -252,7 +252,7 @@ If optional argument SIGN is non-nil, do a combined sign and encrypt."
(when (re-search-forward "^\\[GNUPG:] IMPORT_RES\\>" nil t)
(setq status (buffer-substring (match-end 0)
(progn (end-of-line)(point)))
- status (vconcat (mapcar #'string-to-int (split-string status))))
+ status (vconcat (mapcar #'string-to-number (split-string status))))
(erase-buffer)
(insert (format "Imported %d key(s).
\tArmor contains %d key(s) [%d bad, %d old].\n"
diff --git a/lisp/gnus/pgg-parse.el b/lisp/gnus/pgg-parse.el
index bf04ca914a8..7929b54010d 100644
--- a/lisp/gnus/pgg-parse.el
+++ b/lisp/gnus/pgg-parse.el
@@ -113,7 +113,7 @@
`(mapconcat (lambda (c) (format "%02X" (pgg-char-int c)))
,string "")
;; `(upcase (apply #'format "%02x%02x%02x%02x%02x%02x%02x%02x"
- ;; (string-to-int-list ,string)))
+ ;; (string-to-number-list ,string)))
)
(defmacro pgg-parse-time-field (bytes)
@@ -136,7 +136,7 @@
(defmacro pgg-read-bytes (nbytes)
`(mapcar #'pgg-char-int (pgg-read-bytes-string ,nbytes))
- ;; `(string-to-int-list (pgg-read-bytes-string ,nbytes))
+ ;; `(string-to-number-list (pgg-read-bytes-string ,nbytes))
)
(defmacro pgg-read-body-string (ptag)
@@ -146,7 +146,7 @@
(defmacro pgg-read-body (ptag)
`(mapcar #'pgg-char-int (pgg-read-body-string ,ptag))
- ;; `(string-to-int-list (pgg-read-body-string ,ptag))
+ ;; `(string-to-number-list (pgg-read-body-string ,ptag))
)
(defalias 'pgg-skip-bytes 'forward-char)
diff --git a/lisp/gnus/pop3.el b/lisp/gnus/pop3.el
index b21b3dcd5ae..75efaf4e512 100644
--- a/lisp/gnus/pop3.el
+++ b/lisp/gnus/pop3.el
@@ -398,8 +398,8 @@ If NOW, use that time instead."
"Return the number of messages in the maildrop and the maildrop's size."
(pop3-send-command process "STAT")
(let ((response (pop3-read-response process t)))
- (list (string-to-int (nth 1 (split-string response " ")))
- (string-to-int (nth 2 (split-string response " "))))
+ (list (string-to-number (nth 1 (split-string response " ")))
+ (string-to-number (nth 2 (split-string response " "))))
))
(defun pop3-list (process &optional msg)
@@ -449,7 +449,7 @@ This function currently does nothing.")
"Return highest accessed message-id number for the session."
(pop3-send-command process "LAST")
(let ((response (pop3-read-response process t)))
- (string-to-int (nth 1 (split-string response " ")))
+ (string-to-number (nth 1 (split-string response " ")))
))
(defun pop3-rset (process)
diff --git a/lisp/gnus/qp.el b/lisp/gnus/qp.el
index 1004abeb02b..07ed552ef46 100644
--- a/lisp/gnus/qp.el
+++ b/lisp/gnus/qp.el
@@ -69,9 +69,9 @@ them into characters should be done separately."
(cond ((eq (char-after (1+ (point))) ?\n)
(delete-char 2))
((looking-at "=[0-9A-F][0-9A-F]")
- (let ((byte (string-to-int (buffer-substring (1+ (point))
- (+ 3 (point)))
- 16)))
+ (let ((byte (string-to-number (buffer-substring (1+ (point))
+ (+ 3 (point)))
+ 16)))
(mm-insert-byte byte 1)
(delete-char 3)))
(t
diff --git a/lisp/gnus/spam-report.el b/lisp/gnus/spam-report.el
index e988199755d..ded68aba4ed 100644
--- a/lisp/gnus/spam-report.el
+++ b/lisp/gnus/spam-report.el
@@ -183,14 +183,14 @@ symbol `ask', query before flushing the queue file."
the external program specified in `mm-url-program' to connect to
server."
(with-temp-buffer
- (let ((url (concat "http://" host report)))
+ (let ((url (format "http://%s%s" host report)))
(mm-url-insert url t))))
;;;###autoload
(defun spam-report-url-to-file (host report)
"Collect spam report requests in `spam-report-requests-file'.
Customize `spam-report-url-ping-function' to use this function."
- (let ((url (concat "http://" host report))
+ (let ((url (format "http://%s%s" host report))
(file spam-report-requests-file))
(gnus-make-directory (file-name-directory file))
(gnus-message 9 "Writing URL `%s' to file `%s'" url file)
diff --git a/lisp/gnus/nndiary.el b/lisp/gnus/nndiary.el
index de33cd156c6..e4b087eec2e 100644
--- a/lisp/gnus/nndiary.el
+++ b/lisp/gnus/nndiary.el
@@ -601,7 +601,7 @@ all. This may very well take some time.")
(nnheader-report 'nndiary "Article %s retrieved" id)
;; We return the article number.
(cons (if group-num (car group-num) group)
- (string-to-int (file-name-nondirectory path)))))))
+ (string-to-number (file-name-nondirectory path)))))))
(deffoo nndiary-request-group (group &optional server dont-check)
(let ((file-name-coding-system nnmail-pathname-coding-system))
@@ -820,7 +820,7 @@ all. This may very well take some time.")
;; we should insert it. (This situation should never
;; occur, but one likes to make sure...)
(while (and (looking-at "[0-9]+\t")
- (< (string-to-int
+ (< (string-to-number
(buffer-substring
(match-beginning 0) (match-end 0)))
article)
@@ -1281,14 +1281,14 @@ all. This may very well take some time.")
(nnheader-article-to-file-alist nndiary-current-directory))))
-(defun nndiary-string-to-int (str min &optional max)
- ;; Like `string-to-int' but barf if STR is not exactly an integer, and not
+(defun nndiary-string-to-number (str min &optional max)
+ ;; Like `string-to-number' but barf if STR is not exactly an integer, and not
;; within the specified bounds.
;; Signals are caught by `nndiary-schedule'.
(if (not (string-match "^[ \t]*[0-9]+[ \t]*$" str))
(nndiary-error "not an integer value")
;; else
- (let ((val (string-to-int str)))
+ (let ((val (string-to-number str)))
(and (or (< val min)
(and max (> val max)))
(nndiary-error "value out of range"))
@@ -1315,12 +1315,12 @@ all. This may very well take some time.")
(let ((res (split-string val "-")))
(cond
((= (length res) 1)
- (nndiary-string-to-int (car res) min-or-values max))
+ (nndiary-string-to-number (car res) min-or-values max))
((= (length res) 2)
;; don't know if crontab accepts this, but ensure
;; that BEG is <= END
- (let ((beg (nndiary-string-to-int (car res) min-or-values max))
- (end (nndiary-string-to-int (cadr res) min-or-values max)))
+ (let ((beg (nndiary-string-to-number (car res) min-or-values max))
+ (end (nndiary-string-to-number (cadr res) min-or-values max)))
(cond ((< beg end)
(cons beg end))
((= beg end)